@@ -5,6 +5,9 @@ use sqlx::{
     Postgres,
 };
 
+#[cfg(feature = "async-graphql")]
+use async_graphql::{InputValueError, InputValueResult, Number, ScalarType, Value};
+
 use crate::Geometry;
 
 #[derive(Clone, Debug)]
@@ -45,3 +48,18 @@ impl<'de> sqlx::Decode<'de, Postgres> for Point {
         Ok(Point(point))
     }
 }
+
+#[cfg(feature = "async-graphql")]
+#[async_graphql::Scalar]
+impl ScalarType for Point {
+    fn parse(_value: Value) -> InputValueResult<Self> {
+        Err(InputValueError::custom("parsing not implemented"))
+    }
+
+    fn to_value(&self) -> Value {
+        Value::List(vec![
+            Value::Number(Number::from_f64(self.x()).unwrap()),
+            Value::Number(Number::from_f64(self.y()).unwrap()),
+        ])
+    }
+}
